==> flutter_mylibrary-0.5.86.tar.gz: lib/base/base_mix_request_model_controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_mylibrary/base/request_info.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'base_view_state.dart';

mixin BaseMixRequestModelController on BaseViewState{


  List<RequestInfo> getMixRequestInfo();

  Map<String, HttpData> allHttpDataMap = {};

  Map<String, HttpData> successHttpDataMap = {};


  void refreshData(){
    List<RequestInfo> requestList = getMixRequestInfo();
    requestList.asMap().entries.forEach((item) async{
      RequestInfo requestInfo = item.value;
      int index = item.key;
      if(syncRequest){
        HttpData httpData = await doRequest(requestInfo);
        ///同步请求需要等待所有请求完成再更新页面状态
        allHttpDataMap[requestInfo.url] = httpData;
        if(httpData.success){
          successHttpDataMap[requestInfo.url] = httpData;
        }
        requestInfo.onCompleted?.call(httpData);
        if(index == requestList.length - 1){
          ///完成最后请求
          if(successHttpDataMap.isNotEmpty){
            handleViewState(allHttpDataMap);
          }
        }
      }else{
        doRequest(requestInfo).then((httpData){
          allHttpDataMap[requestInfo.url] = httpData;
          if(httpData.success){
            successHttpDataMap[requestInfo.url] = httpData;
          }
          requestInfo.onCompleted?.call(httpData);
          if(index == requestList.length - 1){
            ///完成最后请求
            handleViewState(allHttpDataMap);
          }
        });
      }
    });
  }

  void handleViewState(Map<String, HttpData> allHttpDataMap){
    if(viewState == ViewState.busy){
      Map<String, HttpError> httpErrorMap = {};
      allHttpDataMap.forEach((url, httpData){
        if(!httpData.success){
          httpErrorMap[url] = httpData.httpError;
        }
      });
      if(httpErrorMap.isEmpty){
        setIdle();
      }else{
        handleHttpError(httpErrorMap);
      }
    }
  }


  void handleHttpError(Map<String, HttpError> httpErrorMap){
    setError(HttpError.emptyMixError(httpErrorMap, syncRequest));
  }



  void requestWhenError(){
    if(viewState == ViewState.error){
      setBusy();
      refreshData();
    }
  }



  @override
  RequestInfo getRequestInfo() {
    return null;
  }


  ///获取一个公共的刷新控件
  Widget buildEasyRefreshWidget({
    ScrollController scrollController,
    Widget footWidget,
    Widget emptyWidget,
    List<Widget> widgetList,
    Widget widget,
    Widget busyWidget,
    bool showErrorWidget = true,
    bool showEmptyWidget = true,
    bool showBusyWidget = true,
    Function onLoad,
    Function onRefresh,
  }){
    return buildBaseViewStateEasyRefresh(
        scrollController: scrollController,
        footWidget: footWidget,
        emptyWidget: emptyWidget,
        widget: widget,
        widgetList: widgetList,
        busyWidget: busyWidget,
        showBusyWidget: showBusyWidget,
        showEmptyWidget: showEmptyWidget,
        showErrorWidget: showErrorWidget,
        onLoad: onLoad,
        onRefresh: onRefresh??(){
          refreshData();
        }
    );
  }

  ///是否同步请求
  bool get syncRequest => false;

}

==> flutter_mylibrary-0.5.87.tar.gz: lib/base/base_mix_request_model_controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_mylibrary/base/request_info.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'base_view_state.dart';

mixin BaseMixRequestModelController on BaseViewState{


  List<RequestInfo> getMixRequestInfo();

  Map<String, HttpData> allHttpDataMap = {};

  Map<String, HttpData> successHttpDataMap = {};


  void refreshData(){
    List<RequestInfo> requestList = getMixRequestInfo();
    requestList.asMap().entries.forEach((item) async{
      RequestInfo requestInfo = item.value;
      int index = item.key;
      if(syncRequest){
        HttpData httpData = await doRequest(requestInfo);
        ///同步请求需要等待所有请求完成再更新页面状态
        allHttpDataMap[requestInfo.url] = httpData;
        if(httpData.success){
          successHttpDataMap[requestInfo.url] = httpData;
        }
        requestInfo.onSuccess?.call(httpData);
        if(index == requestList.length - 1){
          ///完成最后请求
          if(successHttpDataMap.isNotEmpty){
            handleViewState(allHttpDataMap);
          }
        }
      }else{
        doRequest(requestInfo).then((httpData){
          allHttpDataMap[requestInfo.url] = httpData;
          if(httpData.success){
            successHttpDataMap[requestInfo.url] = httpData;
          }
          requestInfo.onSuccess?.call(httpData);
          if(index == requestList.length - 1){
            ///完成最后请求
            handleViewState(allHttpDataMap);
          }
        });
      }
    });
  }

  void handleViewState(Map<String, HttpData> allHttpDataMap){
    if(viewState == ViewState.busy){
      Map<String, HttpError> httpErrorMap = {};
      allHttpDataMap.forEach((url, httpData){
        if(!httpData.success){
          httpErrorMap[url] = httpData.httpError;
        }
      });
      if(httpErrorMap.isEmpty){
        setIdle();
      }else{
        handleHttpError(httpErrorMap);
      }
    }
  }


  void handleHttpError(Map<String, HttpError> httpErrorMap){
    setError(HttpError.emptyMixError(httpErrorMap, syncRequest));
  }



  void requestWhenError(){
    if(viewState == ViewState.error){
      setBusy();
      refreshData();
    }
  }



  @override
  RequestInfo getRequestInfo() {
    return null;
  }


  ///获取一个公共的刷新控件
  Widget buildEasyRefreshWidget({
    ScrollController scrollController,
    Widget footWidget,
    Widget emptyWidget,
    List<Widget> widgetList,
    Widget widget,
    Widget busyWidget,
    bool showErrorWidget = true,
    bool showEmptyWidget = true,
    bool showBusyWidget = true,
    Function onLoad,
    Function onRefresh,
  }){
    return buildBaseViewStateEasyRefresh(
        scrollController: scrollController,
        footWidget: footWidget,
        emptyWidget: emptyWidget,
        widget: widget,
        widgetList: widgetList,
        busyWidget: busyWidget,
        showBusyWidget: showBusyWidget,
        showEmptyWidget: showEmptyWidget,
        showErrorWidget: showErrorWidget,
        onLoad: onLoad,
        onRefresh: onRefresh??(){
          refreshData();
        }
    );
  }

  ///是否同步请求
  bool get syncRequest => false;

}
